@@ -1,20 +1,21 @@
 /*
- *  Copyright (c) 2009 Brian Tarricone <brian@terricone.org>
- *  Copyright (C) 1999 Olivier Fourdan (fourdan@xfce.org)
+ * Copyright (c) 2009 Brian Tarricone <brian@terricone.org>
+ * Copyright (C) 1999 Olivier Fourdan <fourdan@xfce.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
  */
 
 /**
@@ -2138,7 +2139,7 @@ xfce_sm_client_get_priority(XfceSMClient *sm_client)
  *
  * Returns: an opaque object-owned string
  **/
-G_CONST_RETURN gchar *
+const gchar *
 xfce_sm_client_get_client_id(XfceSMClient *sm_client)
 {
     g_return_val_if_fail(XFCE_IS_SM_CLIENT(sm_client), NULL);
@@ -2171,7 +2172,7 @@ xfce_sm_client_get_client_id(XfceSMClient *sm_client)
  * Returns: a file name string, owned by the object or %NULL if
  *          the session client is disabled.
  **/
-G_CONST_RETURN gchar *
+const gchar *
 xfce_sm_client_get_state_file(XfceSMClient *sm_client)
 {
     gchar *resource, *p;
@@ -2233,7 +2234,7 @@ xfce_sm_client_get_state_file(XfceSMClient *sm_client)
  *
  * Returns: an object-owned string
  **/
-G_CONST_RETURN gchar *
+const gchar *
 xfce_sm_client_get_current_directory(XfceSMClient *sm_client)
 {
     g_return_val_if_fail(XFCE_IS_SM_CLIENT(sm_client), NULL);
@@ -2249,7 +2250,7 @@ xfce_sm_client_get_current_directory(XfceSMClient *sm_client)
  *
  * Returns: an object-owned string vector
  **/
-G_CONST_RETURN gchar * G_CONST_RETURN *
+const gchar * const *
 xfce_sm_client_get_restart_command(XfceSMClient *sm_client)
 {
     g_return_val_if_fail(XFCE_IS_SM_CLIENT(sm_client), NULL);
